%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computes normal incidence acoustical and material dynamic properties of sound absorbing 
% rigid or limp frame porous materials following different equivalent fluid models.
%
% Notice
%     Befor using this function, examine the script to well understand what are the
%     inputs and, more particularly, the outputs.  The symbols used here may differ
%     from those used in the litterature.  So pay attention!
%
% Programmed by: Prof. Raymond Panneton, Eng., Ph.D.
% Version: 4
% Date: August 2010
% (c) Universit de Sherbrooke
%
% PREFERRED REFERENCE:
% R. Panneton, "Comments on the limp frame equivalent fluid model for
% porous media," J. Acoust. Soc. Am. 122(6), EL217-222 (2007).
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Define frequency range
clear,clc
frequency=linspace(100,4000,100);
xlabeltype='f';             % Decide which propertiy is plotted as the x variable
                            %   f=frequency
                            %   kL= (wave number in air) * (thickness of sample) (no unit)
ylabeltype='sac';           % Decide which propertiy is plotted as the y variable:
                            %   sac=normal sound absorption; 
                            %   TL=normal transmission loss; 
                            %   rflx=reflection coefficient; 
                            %   zsneq=normalized surface impedance of the equivalente fluid 
                            %   roeqn=normalized dynamic density of the equivalente fluid
                            %   Keqn=normalized dynamic bulk modulus of the equivalente fluid
                            %   zcneq=normalized characteristic impedance of the equivalente fluid; 
                            %   keq=wcomplex wave number of the equivalente fluid
%% Define thickness of sample
thickness=0.030;            %m
%% Define type of material and modelling
model='champoux';           %See Equifluid.m for other models
frame='rigid';              %'rigid' or 'limp' frame
idiss='total';              %'viscous', 'thermal' or 'total' dissipation
%% Define macroscopic properties of material (Adjust following the model to use in Equifluid.m)
porosity=0.99;              %no units
resistivity=11000;          %Ns/m^4
tortuosity=1.01;            %no units
viscouslength=90e-6;        %m
thermallength=180e-6;       %m
bulkdensity=8.21;           %kg/m (not used if "rigid" frame)
R=[porosity resistivity tortuosity viscouslength thermallength];
%% Define air conditions
To=18;                      %Air temperature (C)
Po=101300;                  %Static (atmospheric) pressure (Pa)
HR=40;                      %Relative humidity (%)
[ro,co]=propair(To,Po,HR);
%% Pre-calculations
L=thickness;
ro1=bulkdensity;
w=2*pi*frequency;
%% Calculation with Equifluid.m
[sac,TL,rflx,zsneq,roeqn,Keqn,zcneq,keq]=eqfluid(w,R,ro1,L,To,Po,HR,model,frame,idiss);
%% Select x and y
switch xlabeltype
    case 'f'
        x=frequency;
    case 'kL'
        x=w/co*L;
    otherwise
        errordlg({'x-variable must be ''f'' or ''kL''','Check case-sensitive syntax'},'Error Message','modal');
        return
end
switch ylabeltype
    case 'sac'
        y=sac;
    case 'TL'
        y=TL;
    case 'rflx'
        y=rflx;
    case 'zsneq'
        y=zsneq;       
    case 'roeqn'
        y=roeqn;
    case 'Keqn'
        y=Keqn;
    case 'zcneq'
        y=zcneq;
    case 'keq'
        y=keq;
    otherwise
        errordlg({'y-variable not valid','Check case-sensitive syntax'},'Error Message','modal');
        return        
end
%% Prepare figure
figure(101); clf
set(gcf,'Color','w');
set(gca,'FontSize',16,'box','on','linewidth',1.1)
%% Plot
if isreal(y)
    h=plot(x,y);
    set(h(1),'LineStyle','-','Color',[0 0 1],'LineWidth',4)
else
    h=plot(x,real(y),'b',x,imag(y),'r');
    set(h(1),'LineStyle','-','LineWidth',4)
    set(h(2),'LineStyle','--','LineWidth',4)
end
%% Label x-axis
switch xlabeltype
    case 'f'
        set(gca,'xlim',[0 max(x)]);
        h=xlabel('{\itFrequency} (Hz)');
        set(h,'FontSize',18,'FontWeight','normal','fontname','times')
    case 'kL'
        set(gca,'xlim',[0 max(x)]);
        h=xlabel('{\itk \cdot L}');
        set(h,'FontSize',18,'FontWeight','normal','fontname','times')
end
%% Label y-axis
switch ylabeltype
    case 'sac'
        set(gca,'ylim',[0 1]);
        h=ylabel('\alpha');
        set(h,'FontSize',22,'FontWeight','normal', 'fontname','times')
    case 'TL'
        set(gca,'ylim',[0 60]);
        h=ylabel('{\itTL} (dB)');
        set(h,'FontSize',18,'FontWeight','normal', 'fontname','times')       
    case 'rflx'
        set(gca,'ylim',[-1 1]);
        h=ylabel('\itR');
        set(h,'FontSize',18,'FontWeight','normal', 'fontname','times')
        h=legend('Real','Imag',4);
        set(h,'FontSize',16,'Fontname','Times')      
    case 'zsneq'
        set(gca,'ylim',[-10 10]);
        h=ylabel('\itZ_s/Z_0');
        set(h,'FontSize',18,'FontWeight','normal', 'fontname','times')
        h=legend('Resistance','Reactance',4);
        set(h,'FontSize',16,'Fontname','Times')
    case 'roeqn'
        set(gca,'ylim',[-15 15]);
        h=ylabel('\itZ_c/Z_0');
        set(h,'FontSize',18,'FontWeight','normal', 'fontname','times')
        h=legend('Resistance','Reactance',4);
        set(h,'FontSize',16,'Fontname','Times')        
    case 'Keqn'
        set(gca,'ylim',[-10 10]);
        h=ylabel('\itZ_c/Z_0');
        set(h,'FontSize',18,'FontWeight','normal', 'fontname','times')
        h=legend('Resistance','Reactance',4);
        set(h,'FontSize',16,'Fontname','Times')        
    case 'zcneq'
        set(gca,'ylim',[-10 10]);
        h=ylabel('\itZ_c/Z_0');
        set(h,'FontSize',18,'FontWeight','normal', 'fontname','times')
        h=legend('Resistance','Reactance',4);
        set(h,'FontSize',16,'Fontname','Times')        
    case 'keq'
        set(gca,'ylim',[-1 1]*max(zcneq)/2*max(w)/co);
        h=ylabel('\itk/k_0');
        set(h,'FontSize',18,'FontWeight','normal', 'fontname','times')
        h=legend('Real','Imag',4);
        set(h,'FontSize',16,'Fontname','Times')      
end
grid
%% Print good quality graph in a temp tif file
print -r300 -dtiff 'temp.tif'
%% Create a matrix containing the computed acoustical properties 
%  SUCH AS A B&K file or a Tube-X file compatible with FOAM-X program
tbx=[frequency.' sac.' real(rflx).' imag(rflx).' real(zsneq).' imag(zsneq).'];
%% Create a matrix containing the computed dynamic material properties 
%  Compatible with FOAM-X program
req=[frequency.' real(roeqn).' imag(roeqn).' real(Keqn).' imag(Keqn).'];
