function [alpha,TL,rflx,zsneq,roeqn,Keqn,zcneq,k]=eqfluid(w,R,ro1,d,To,Po,HR,model,frame,idiss);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Computes the acoustical and dynamic properties of sound absorbing rigid or limp
% frame porous materials following different equivalent fluid models.
%
% Notice
%     Befor using this function, examine the script to well understand what are the
%     inputs and, more particularly, the outputs.  The symbols used here may differ
%     from those used in the litterature.  So pay attention!
%
% Programmed by: Prof. Raymond Panneton, Eng., Ph.D.
% Version: 4
% Date: August 2010
% (c) Universit de Sherbrooke
%
% PREFERRED REFERENCE:
% R. Panneton, "Comments on the limp frame equivalent fluid model for
% porous media," J. Acoust. Soc. Am. 122(6), EL217-222 (2007).
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Input parameters:
%   - w : angular frequency (=2*pi*f)
%   - R : array containing the material properties (see below for a given model)
%   - ro1 : bulk density of the material (not used if rigid frame)
%   - d : thickness of the material in meter (m)
%   - To : temperature of air in celsius ('C)
%   - Po : static (atmospheric) pressure in Pascal (Pa)
%   - HR : relative humidity in percentage (%)
%   - model : one of the following
%             'delany'  = delany et bazley (D&B)
%             'miki'    = miki (comme D&B, but better at low frequencies)
%             'mikim'   = mikim (Miki modified, account for porosity and tortuosity)
%             'champoux' = johnson-champoux (THE MOST USED MODEL) - 5 parameters
%             'lafarge'  = johnson-lafarge (More accurate than johnson-champoux - 6 parameters
%             'wilson'   = relaxation based model
%             'pride'    = pride-lafarge (the most accurate) - 7 parameters. It corrects the 
%                          low-frequency imaginary part of the viscous permeability which is 
%                          underestimated by the Johnson et al. model.
%   - frame : "limp" or "rigid" (rigid means motionless)
%   - idiss : "total" = accounts for viscous and thermal dissipations.
%             "viscous" = only accounts for the viscous dissipation.
%             "thermal" = only accounts for the thermal dissipation.
%
% Material Properties
%   Depending n the model, the input array R is defined as described below.
%   If model=='delany'
%       R=[sig(Ns/m4)]     
%   If model=='miki'
%       R=[sig(Ns/m4)]
%   If model=='mikim'
%       R=[phi(-),sig(Ns/m4),tor(-),Sf(-)]
%   If model=='champoux'
%       R=[phi(-),sig(Ns/m4),tor(-),lcv(m),lct(m)]
%   If model=='lafarge'
%       R=[phi(-),sig(Ns/m4),tor(-),lcv(m),lct(m),kop(m)]
%   If model=='wilson'
%       R=[phi(-),aoo(-),tv(s),tt(s),Koo(Pa)] 
%   If model=='pride'
%       R=[phi(-),sig(Ns/m4),tor(-),lcv(m),lct(m),kop(m),tor0(-)]
%
% List of symbols
%   phi: open porosity between [0,1[ (no units)
%   sig: static airflow resistivity in Ns/m4 (or MKS rayls/m)
%   tor: tortuosity (or structure factor) (no units)
%   lcv: viscous characteristic length in meter (m)
%   lct: thermal characteristic length in meter (m)
%   kop: thermal static permeability in meter (m)
%   tor0: static tortuosity (no units)
%   Sf: shape factor following Miki's works (no units)
%
% Output parameters
%   - alpha : normal incidence sound absorption coefficient (real)
%   - TL : normal incidence sound transmission loss in dB (real)
%   - reflx : reflection coefficient (complex)
%   - zsneq : normalized surface impedance (complex, normalized by air impedance Zo = rho0*co)
%   - roeqn : normalized dynamic density of equivalent fluid (complex, normalized by air density rho0)
%   - Keqn : normalized dynamic bulk modulus of equivalent fluid (complex, normalized by static pressure Po)
%   - zcneq : normalized characteristic impedance of equivalent fluid (complex, normalized by air impedance Zo = rho0*co)
%   - k : complex wave number in equivalent fluide in 1/meter (1/m)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Set 0 rad/s to a very small value
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if w(1)==0; w(1)=1e-12; end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Air properties
%ro=rho0=volume density (kg/m)
%co=sound speed (m/s)
%vis=absolute (or dynamic) viscosity in Ns/m
%gamma=specific heat ratio (no units)
%B2=Prandtl number (no units)
%Cp=Constant Pressure Spectfic Heat in J/kgK
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[ro,co,vis,gamma,B2,Cp,kappla]=propair(To,Po,HR);
zair=(ro*co).'; %zair=Zo = impedance of air.
kair=w/co;      %wave number in air

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Effective properties of fluid phase
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch model
    case 'delany'
        phi=1; sig=R(1); 
        bidz=ro*co*(1+0.0571*(2*pi*sig/ro./w).^0.754-j*0.087*(2*pi*sig/ro./w).^0.732);
        bidk=w/co.*(1+0.0978*(2*pi*sig/ro./w).^0.700-j*0.189*(2*pi*sig/ro./w).^0.595);
        reff=bidz.*bidk./w;
        Keff=reff.*(w./bidk).^2;
    case 'miki'
        phi=1; sig=R(1); 
        bidz=ro*co*(1+0.0700*(2*pi*sig./w).^0.632-j*0.107*(2*pi*sig./w).^0.632);
        bidk=w/co.*(1+0.1090*(2*pi*sig./w).^0.618-j*0.160*(2*pi*sig./w).^0.618);
        reff=bidz.*bidk./w;
        Keff=reff.*(w./bidk).^2;
    case 'mikim'
        phi=R(1); sig=R(2); tor=R(3); Sf=R(4);
        sig=Sf^2*phi/tor*sig;
        bidz=ro*co*tor/phi*(1+0.0700*(2*pi*sig./w).^0.632-j*0.107*(2*pi*sig./w).^0.632);
        bidk=w/co*tor.*(1+0.1090*(2*pi*sig./w).^0.618-j*0.160*(2*pi*sig./w).^0.618);
        reff=bidz.*bidk./w;
        Keff=reff.*(w./bidk).^2;        
    case 'champoux' % See table p. 24 of R. Panneton PhD dissertaion thesis
        phi=R(1); sig=R(2); tor=R(3); lcv=R(4); lct=R(5);
        H=sig^2*lcv^2*phi^2/4/tor^2/vis/ro;         g=sqrt(1+j*w/H);        
        reff=tor*ro*(1+sig*phi./(j*w*ro*tor).*g);
    	Hp=16*vis/B2/lct^2/ro;                      gp=sqrt(1+j*w/Hp);	 	
        Keff=gamma*Po./(gamma-(gamma-1)./(1+Hp/j/2./w.*gp));
    case 'champoux2' % See table p. 24 of R. Panneton PhD dissertaion thesis
        phi=R(1); sig=R(2); tor=R(3); lcv=R(4); lct=R(5);
        M=8*tor*vis/phi/sig/lcv^2;
        wv=sig*phi/tor/ro;
        wr=w/wv;
        GR=1/sqrt(2)*sqrt(1+sqrt(1+(M*wr/2).^2));
        GI=M*wr/4./GR;
        reff=(ro*tor+sig*phi./w.*GI)-j*sig*phi./w.*GR;
    	Hp=16*vis/B2/lct^2/ro;                      gp=sqrt(1+j*w/Hp);	 	
        Keff=gamma*Po./(gamma-(gamma-1)./(1+Hp/j/2./w.*gp));
    case 'lafarge' % Viscous part unchanged compared to !champox model' (H, g and reff), only Keff is modified
        phi=R(1); sig=R(2); tor=R(3); lcv=R(4); lct=R(5); kop=R(6); 
        H=sig^2*lcv^2*phi^2/4/tor^2/vis/ro;         g=sqrt(1+j*w/H);        
        reff=tor*ro*(1+sig*phi./(j*w*ro*tor).*g);              
        nup=vis/ro/B2; Mp=8*kop./lct.^2/phi;        wtl=phi*nup./kop;  gp=sqrt(1+j*Mp./2.*w./wtl);
        Keff=gamma*Po./(gamma-(gamma-1)./(1-j*wtl./w.*gp));        
    case 'wilson'
        phi=R(1); aoo=R(2); tv=R(3); tt=R(4); Koo=R(5); 
        reff=ro*aoo./(1-(1+j*w*tv).^(-0.5));           
        Keff=Koo./(1+(gamma-1)*(1+j*w*tt).^(-0.5));
    case 'pride' % Thermal part unchanged compared to 'lafarge model' (Keff), only reff is modified by the introduction of a supplementary parametter, p
        phi=R(1); sig=R(2); tor=R(3); lcv=R(4); lct=R(5); kop=R(6); tor0=R(7);
        M = 8*vis*tor/phi/sig/lcv^2; p = M/4/(tor0/tor-1);
        H1=sig^2*lcv^2*phi^2*p^2/4/tor^2/vis/ro;        H2=phi*sig*p/ro/tor;        H3=phi*sig*(1-p)/ro/tor;         g=sqrt(1+j*w/H1);        reff=tor*ro*(1+H2*g./(j*w)+H3./(j*w));
        Keff=gamma*Po./(gamma-(gamma-1)./(1-j*phi*kappla/kop/Cp/ro./w.*sqrt(1+j*4*kop^2*Cp*ro*w./kappla./lct.^2./phi^2)));
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Modified effective density if frame is limp.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if strcmp(frame,'limp')    
    rstilde=ro1+phi*ro*(1-ro./reff);
    gamtilde=phi*ro./reff-1;
    reff=1./(1./reff+gamtilde.^2./phi./rstilde);
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Account for total, viscous or thermal dissipation
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
switch idiss
    case 'total'
        % do nothing
    case 'viscous'
        Keff=gamma*Po;  % adiabatic value (no imag part = no thermal dissipation)
    case 'thermal'
        reff=ro;        % real density (no imag part = no viscous dissipation)
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute the normalized dynamic properties of the
% equivalent fluid medium (not only of the fluid phase)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
roeqn=reff/ro/phi;   %Divide by open porosity to obtain the dynamic properties of the equivalent fluid
Keqn=Keff/Po/phi;    %from the effective properties of the fluid phase only.  Then normalized by ro or Po.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute normalized characteristic impedance of the
% equivalent fluid such as if it were measured in
% impedance tube. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
zc=sqrt(reff.*Keff);   
zcneq=zc/zair/phi;    

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute complex wavenumber
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
k=w.*sqrt(reff./Keff);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute normalized surface impedance of the
% equivalent fluid
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
zsneq=-j*zc.*cot(k*d)/phi/zair;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute sound reflection and absorption coefficient
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
rflx=(zsneq-1)./(zsneq+1);
alpha=(1-abs(rflx).^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Compute TL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
tau2=(abs(2./sin(k*d)./(2*coth(j*k*d)+zc/phi/zair+phi*zair./zc)).^2);
TL=-10*log10(tau2);

return
